==> cmsmadesimple-1.5.3.tgz: cms/modules/Printing/lang/ext/cs_CZ.php <==
<?php
$lang['friendlyname'] = 'Str&aacute;nky pro tisk';
$lang['description'] = 'Tento modul je lehce upraviteln&yacute; zpusob jak poskytovat str&aacute;nky vhodn&eacute; pro tisk. Volitelně je možn&eacute; vytv&aacute;řet za běhu PDF soubory s hlavn&iacute;m obsahem.';
$lang['postinstall'] = 'Modul byl &uacute;spě&scaron;ně nainstalov&aacute;n';
$lang['confirmuninstall'] = 'Opravdu chcete tento modul odinstalovat?';
$lang['postuninstall'] = 'Modul byl &uacute;spě&scaron;ně odinstalov&aacute;n';
$lang['linktemplate'] = '&Scaron;ablona odkazu';
$lang['printtemplate'] = '&Scaron;ablona tisku';
$lang['pdftemplate'] = '&Scaron;ablona PDF';
$lang['templatesaved'] = '&Scaron;ablona byla uložena';
$lang['templatereset'] = '&Scaron;ablona byla nastavena na v&yacute;choz&iacute; hodnoty';
$lang['confirmresettemplate'] = 'Opravdu chcete nastavit &scaron;ablonu na v&yacute;choz&iacute; hodnoty?';
$lang['reset'] = 'Nastavit v&yacute;choz&iacute;';
$lang['save'] = 'Uložit';
$lang['upgraded'] = 'byl aktualizov&aacute;n na verzi %s';
$lang['savetemplate'] = 'Uložit &scaron;ablonu';
$lang['savesettings'] = 'Uložit nastaven&iacute;';
$lang['settings'] = 'Nastaven&iacute;';
$lang['settingssaved'] = 'Nastaven&iacute; uloženo';
$lang['pdfheader'] = 'PDF hlavička';
$lang['headerfontsize'] = 'Velikost p&iacute;sma hlavičky';
$lang['contentfontsize'] = 'Velikost p&iacute;sma obsahu';
$lang['fonttypetext'] = 'Typ fontu';
$lang['fontserif'] = 'Serif';
$lang['fontsansserif'] = 'Sans Serif';
$lang['orientation'] = 'Orientace';
$lang['landscape'] = 'Na &scaron;&iacute;řku';
$lang['portrait'] = 'Na v&yacute;&scaron;ku';
$lang['pdffooter'] = '';
$lang['pdffooterhelp'] = '';
$lang['template'] = '&Scaron;ablona';
$lang['notemplatecontent'] = 'Nebyl zad&aacute;n nov&yacute; obsah &scaron;ablony...';
$lang['defaultlinktext'] = 'Vytisknout tuto str&aacute;nku';
$lang['defaultpdflinktext'] = 'Vytvořit PDF';
$lang['backbuttontext'] = 'Zpět';
$lang['overridestylereset'] = 'Nadřazen&yacute; styl byl vynulov&aacute;n';
$lang['overridestylesaved'] = 'Nadřazen&yacute; styl byl uložen';
$lang['overridestyle'] = 'Nadřazen&yacute; styl';
$lang['confirmresetstyle'] = 'Opravdu chcete vynulovat styl?';
$lang['stylesheet'] = 'Styl';
$lang['help_text'] = 'Potlačit v&yacute;choz&iacute; text odkazu tisk/PDF';
$lang['help_pdf'] = 'Nastavte na &#039;true&#039; pro zobrazen&iacute; odkazu pro generov&aacute;n&iacute; souboru PDF z hlavn&iacute; obsahov&eacute; str&aacute;nky m&iacute;sto tisku';
$lang['help_popup'] = 'Nastavte na &#039;true&#039; a str&aacute;nka pro tisk se otevře v nov&eacute;m okně.';
$lang['help_script'] = 'Nastavte na &#039;true&#039; a bude použit javascript automatick&eacute; zobrazen&iacute; tiskov&eacute;ho dialogu';
$lang['help_showbutton'] = 'Nastavte na &#039;true&#039; pro zobrazen&iacute; grafick&eacute;ho tlač&iacute;tka';
$lang['help_class'] = 'Tř&iacute;da pro odkaz, v&yacute;choz&iacute; &#039;noprint&#039;';
$lang['help_src_img'] = 'Zobrazit tento obr&aacute;zek m&iacute;sto v&yacute;choz&iacute;ho';
$lang['help_class_img'] = 'Tř&iacute;da <img> tagu při nastaven&eacute;m showbutton';
$lang['help_more'] = 'Vložit dodatečn&eacute; volby do odkazu <a>';
$lang['help_onlyurl'] = 'Vytvoř&iacute; pouze url, ne kompletn&iacute; odkaz';
$lang['help'] = '<b>Co děl&aacute; tento modul?</b>
<br/>
Tento modul umožňuje vložen&iacute; odkazu do str&aacute;nek/&scaron;ablon, kter&yacute; naviguje n&aacute;v&scaron;těvn&iacute;ky na verzi vhodněj&scaron;&iacute; pro tisk. Může b&yacute;t nastaveno mnoho parametrů pro &uacute;pravu vzhledu odkazů a str&aacute;nek tisku podle va&scaron;ich představ. Od verze 0.2.0 může b&yacute;t nastaven parametr on-the-fly vytv&aacute;řen&iacute; PDF souborů.
<br/>
Moment&aacute;lně modul podporuje pouze &quot;plain&quot; obsahov&eacute; str&aacute;nky, bez redirekc&iacute; modulů atd. Stejně tak pracuje vestavěn&aacute; funkcionalita tisku v CMSms.

<br/><br/>
<b>Jak se použ&iacute;v&aacute; tento modul?</b>
<br/>
Nainstalovat modul, a v administračn&iacute;m rozhran&iacute; přezkou&scaron;et/změnit &scaron;ablony pro odkaz a str&aacute;nky tisku
<br/>
Ve Va&scaron;em obsahu nebo &scaron;abloně vložit něco jako:
<pre>
{cms_module module=&#039;printing&#039; <i>params</i>}
</pre>
a pot&eacute; se link objev&iacute; na str&aacute;nk&aacute;ch.
<br/>
';
$lang['utma'] = '156861353.4545864025444168000.1227726513.1235876853.1235894120.23';
$lang['utmz'] = '156861353.1235854022.19.6.utmccn=(referral)|utmcsr=miditower|utmcct=/cms/admin/listmodules.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/Printing/lang/ext/cs_CZ.php <==
<?php
$lang['friendlyname'] = 'Str&aacute;nky pro tisk';
$lang['description'] = 'Tento modul je lehce upraviteln&yacute; zpusob jak poskytovat str&aacute;nky vhodn&eacute; pro tisk. Volitelně je možn&eacute; vytv&aacute;řet za běhu PDF soubory s hlavn&iacute;m obsahem.';
$lang['postinstall'] = 'Modul byl &uacute;spě&scaron;ně nainstalov&aacute;n';
$lang['confirmuninstall'] = 'Opravdu chcete tento modul odinstalovat?';
$lang['postuninstall'] = 'Modul byl &uacute;spě&scaron;ně odinstalov&aacute;n';
$lang['linktemplate'] = '&Scaron;ablona odkazu';
$lang['printtemplate'] = '&Scaron;ablona tisku';
$lang['pdftemplate'] = '&Scaron;ablona PDF';
$lang['templatesaved'] = '&Scaron;ablona byla uložena';
$lang['templatereset'] = '&Scaron;ablona byla nastavena na v&yacute;choz&iacute; hodnoty';
$lang['confirmresettemplate'] = 'Opravdu chcete nastavit &scaron;ablonu na v&yacute;choz&iacute; hodnoty?';
$lang['reset'] = 'Nastavit v&yacute;choz&iacute;';
$lang['save'] = 'Uložit';
$lang['upgraded'] = 'byl aktualizov&aacute;n na verzi %s';
$lang['savetemplate'] = 'Uložit &scaron;ablonu';
$lang['savesettings'] = 'Uložit nastaven&iacute;';
$lang['pdfsettings'] = 'Nastaven&iacute; PDF';
$lang['pdfsettingssaved'] = 'Nastaven&iacute; PDF byla uložena';
$lang['pdfheader'] = 'PDF hlavička';
$lang['pdfenable'] = 'Povolit generov&aacute;n&iacute; PDF';
$lang['pdfenablehelp'] = 'Mějte na vědom&iacute;, že že generov&aacute;n&iacute; PDF je pouze velice jednoduch&yacute; v&yacute;stup z&aacute;kladn&iacute;ho obsahu do souboru. Použ&iacute;vejte ho dle libosti, ale nestěžujte si na kvalitu v&yacute;stupu.';
$lang['headerfontsize'] = 'Velikost p&iacute;sma hlavičky';
$lang['contentfontsize'] = 'Velikost p&iacute;sma obsahu';
$lang['fonttypetext'] = 'Typ fontu';
$lang['fontserif'] = 'Serif';
$lang['fontsansserif'] = 'Sans Serif';
$lang['orientation'] = 'Orientace';
$lang['landscape'] = 'Na &scaron;&iacute;řku';
$lang['portrait'] = 'Na v&yacute;&scaron;ku';
$lang['pdffooter'] = '';
$lang['pdffooterhelp'] = '';
$lang['template'] = '&Scaron;ablona';
$lang['notemplatecontent'] = 'Nebyl zad&aacute;n nov&yacute; obsah &scaron;ablony...';
$lang['defaultlinktext'] = 'Vytisknout tuto str&aacute;nku';
$lang['defaultpdflinktext'] = 'Vytvořit PDF';
$lang['backbuttontext'] = 'Zpět';
$lang['overridestylereset'] = 'Nadřazen&yacute; styl byl vynulov&aacute;n';
$lang['overridestylesaved'] = 'Nadřazen&yacute; styl byl uložen';
$lang['overridestyle'] = 'Nadřazen&yacute; styl';
$lang['confirmresetstyle'] = 'Opravdu chcete vynulovat styl?';
$lang['stylesheet'] = 'Styl';
$lang['help_text'] = 'Potlačit v&yacute;choz&iacute; text odkazu tisk/PDF';
$lang['help_pdf'] = 'Nastavte na &#039;true&#039; pro zobrazen&iacute; odkazu pro generov&aacute;n&iacute; souboru PDF z hlavn&iacute; obsahov&eacute; str&aacute;nky m&iacute;sto tisku';
$lang['help_popup'] = 'Nastavte na &#039;true&#039; a str&aacute;nka pro tisk se otevře v nov&eacute;m okně.';
$lang['help_script'] = 'Nastavte na &#039;true&#039; a bude použit javascript automatick&eacute; zobrazen&iacute; tiskov&eacute;ho dialogu';
$lang['help_showbutton'] = 'Nastavte na &#039;true&#039; pro zobrazen&iacute; grafick&eacute;ho tlač&iacute;tka';
$lang['help_class'] = 'Tř&iacute;da pro odkaz, v&yacute;choz&iacute; &#039;noprint&#039;';
$lang['help_src_img'] = 'Zobrazit tento obr&aacute;zek m&iacute;sto v&yacute;choz&iacute;ho';
$lang['help_class_img'] = 'Tř&iacute;da <img> tagu při nastaven&eacute;m showbutton';
$lang['help_more'] = 'Vložit dodatečn&eacute; volby do odkazu <a>';
$lang['help_onlyurl'] = 'Vytvoř&iacute; pouze url, ne kompletn&iacute; odkaz';
$lang['help_includetemplate'] = 'Pokud je nastaveno &#039;true&#039;, proces tisku/vytv&aacute;řen&iacute; pdf zpracuje kompletn&iacute; &scaron;ablonu, ne pouze obsah. Toto pravděpodobně potřebuje &uacute;pravu stylu tisku s povolen&yacute;m typem media &#039;print&#039;.';
$lang['help'] = '<b>Co děl&aacute; tento modul?</b>
<br/>
Tento modul umožňuje vložen&iacute; odkazu do str&aacute;nek/&scaron;ablon, kter&yacute; naviguje n&aacute;v&scaron;těvn&iacute;ky na verzi vhodněj&scaron;&iacute; pro tisk. Může b&yacute;t nastaveno mnoho parametrů pro &uacute;pravu vzhledu odkazů a str&aacute;nek tisku podle va&scaron;ich představ. Od verze 0.2.0 může b&yacute;t nastaven parametr on-the-fly vytv&aacute;řen&iacute; PDF souborů.
<br/>
Moment&aacute;lně modul podporuje pouze &quot;plain&quot; obsahov&eacute; str&aacute;nky, bez redirekc&iacute; modulů atd. Stejně tak pracuje vestavěn&aacute; funkcionalita tisku v CMSms.

<br/><br/>
<b>Jak se použ&iacute;v&aacute; tento modul?</b>
<br/>
Nainstalovat modul, a v administračn&iacute;m rozhran&iacute; přezkou&scaron;et/změnit &scaron;ablony pro odkaz a str&aacute;nky tisku
<br/>
Ve Va&scaron;em obsahu nebo &scaron;abloně vložit něco jako:
<pre>
{cms_module module=&#039;printing&#039; <i>params</i>}
</pre>
a pot&eacute; se link objev&iacute; na str&aacute;nk&aacute;ch.
<br/>
';
$lang['utma'] = '156861353.3769824904990279700.1249913289.1249913289.1249913289.1';
$lang['utmb'] = '156861353.1.10.1249913289';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = '1229762881-19854751-99654968';
$lang['qcb'] = '1368372279';
?>
